==> jc-1.4.0.tar.gz: java/awt/image/FilteredImageSource.h <==
// public class java.awt.image.FilteredImageSource

// class file dependencies
// @dep_class a394be71891508b3 java_awt_image_FilteredImageSource
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_FilteredImageSource_H_
#define _JC_java_awt_image_FilteredImageSource_H_

// Forward structure declarations
struct _jc_java_awt_image_ImageConsumer$object;
struct _jc_java_awt_image_ImageFilter$object;
struct _jc_java_awt_image_ImageProducer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_awt_image_FilteredImageSource$sub_refs	_jc_java_awt_image_FilteredImageSource$sub_refs;
typedef struct _jc_java_awt_image_FilteredImageSource$sub_nonrefs	_jc_java_awt_image_FilteredImageSource$sub_nonrefs;
typedef struct _jc_java_awt_image_FilteredImageSource$refs	_jc_java_awt_image_FilteredImageSource$refs;
typedef struct _jc_java_awt_image_FilteredImageSource$nonrefs	_jc_java_awt_image_FilteredImageSource$nonrefs;
typedef struct _jc_java_awt_image_FilteredImageSource$object	_jc_java_awt_image_FilteredImageSource$object;

typedef const struct _jc_java_awt_image_FilteredImageSource$vmethods	_jc_java_awt_image_FilteredImageSource$vmethods;
typedef const struct _jc_java_awt_image_FilteredImageSource$vtable	_jc_java_awt_image_FilteredImageSource$vtable;
typedef const struct _jc_java_awt_image_FilteredImageSource$vtype	_jc_java_awt_image_FilteredImageSource$vtype;

// Constructors
extern void _jc_java_awt_image_FilteredImageSource$method$_init$1dc600336020525c(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *, struct _jc_java_awt_image_ImageFilter$object *);

// Virtual methods
extern void _jc_java_awt_image_FilteredImageSource$method$addConsumer$280f4229ae568632(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
extern jboolean _jc_java_awt_image_FilteredImageSource$method$isConsumer$2e7ee3184ebf4388(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
extern void _jc_java_awt_image_FilteredImageSource$method$removeConsumer$c1effed99882a87d(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
extern void _jc_java_awt_image_FilteredImageSource$method$requestTopDownLeftRightResend$9c3b642896e809d4(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
extern void _jc_java_awt_image_FilteredImageSource$method$startProduction$34c5bb40595e132a(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
extern void _jc_java_awt_image_FilteredImageSource$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$addConsumer$280f4229ae568632;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$isConsumer$2e7ee3184ebf4388;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$removeConsumer$c1effed99882a87d;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$requestTopDownLeftRightResend$9c3b642896e809d4;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$startProduction$34c5bb40595e132a;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_image_FilteredImageSource$vmethods {
	void	(*addConsumer$280f4229ae568632)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
	jboolean	(*isConsumer$2e7ee3184ebf4388)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
	void	(*removeConsumer$c1effed99882a87d)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
	void	(*requestTopDownLeftRightResend$9c3b642896e809d4)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
	void	(*startProduction$34c5bb40595e132a)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *);
};

// Vtable
struct _jc_java_awt_image_FilteredImageSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_FilteredImageSource$vmethods	java_awt_image_FilteredImageSource;
};

// Vtype
struct _jc_java_awt_image_FilteredImageSource$vtype {
	_jc_type			type;
	_jc_java_awt_image_FilteredImageSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_FilteredImageSource$sub_refs {
	struct _jc_object	*ip;
	struct _jc_java_awt_image_ImageFilter$object	*filter;
	struct _jc_java_util_Hashtable$object	*consumers;
};

// Reference instance fields (object)
struct _jc_java_awt_image_FilteredImageSource$refs {
    _jc_java_awt_image_FilteredImageSource$sub_refs	java_awt_image_FilteredImageSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_FilteredImageSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_FilteredImageSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_FilteredImageSource$sub_nonrefs	java_awt_image_FilteredImageSource;
};

// Object instance structure
struct _jc_java_awt_image_FilteredImageSource$object {
	_jc_java_awt_image_FilteredImageSource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_FilteredImageSource$vtype	*vtype;
	_jc_java_awt_image_FilteredImageSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_FilteredImageSource$vtype _jc_java_awt_image_FilteredImageSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_FilteredImageSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_FilteredImageSource$class_object;

#endif	/* _JC_java_awt_image_FilteredImageSource_H_ */

==> jc-1.4.6.tar.gz: java/awt/image/FilteredImageSource.h <==
// public class java.awt.image.FilteredImageSource

// class file dependencies
// @dep_class a394be71891508b3 java_awt_image_FilteredImageSource
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_image_FilteredImageSource_H_
#define _JC_java_awt_image_FilteredImageSource_H_

// Forward structure declarations
struct _jc_java_awt_image_ImageConsumer$object;
struct _jc_java_awt_image_ImageFilter$object;
struct _jc_java_awt_image_ImageProducer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_awt_image_FilteredImageSource$sub_refs	_jc_java_awt_image_FilteredImageSource$sub_refs;
typedef struct _jc_java_awt_image_FilteredImageSource$sub_nonrefs	_jc_java_awt_image_FilteredImageSource$sub_nonrefs;
typedef struct _jc_java_awt_image_FilteredImageSource$refs	_jc_java_awt_image_FilteredImageSource$refs;
typedef struct _jc_java_awt_image_FilteredImageSource$nonrefs	_jc_java_awt_image_FilteredImageSource$nonrefs;
typedef struct _jc_java_awt_image_FilteredImageSource$object	_jc_java_awt_image_FilteredImageSource$object;

typedef const struct _jc_java_awt_image_FilteredImageSource$vmethods	_jc_java_awt_image_FilteredImageSource$vmethods;
typedef const struct _jc_java_awt_image_FilteredImageSource$vtable	_jc_java_awt_image_FilteredImageSource$vtable;
typedef const struct _jc_java_awt_image_FilteredImageSource$vtype	_jc_java_awt_image_FilteredImageSource$vtype;

// Constructors
extern void _jc_java_awt_image_FilteredImageSource$method$_init$1dc600336020525c(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *, struct _jc_java_awt_image_ImageFilter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_image_FilteredImageSource$method$addConsumer$280f4229ae568632(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_image_FilteredImageSource$method$isConsumer$2e7ee3184ebf4388(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_FilteredImageSource$method$removeConsumer$c1effed99882a87d(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_FilteredImageSource$method$requestTopDownLeftRightResend$9c3b642896e809d4(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_FilteredImageSource$method$startProduction$34c5bb40595e132a(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_image_FilteredImageSource$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$addConsumer$280f4229ae568632;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$isConsumer$2e7ee3184ebf4388;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$removeConsumer$c1effed99882a87d;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$requestTopDownLeftRightResend$9c3b642896e809d4;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$startProduction$34c5bb40595e132a;
extern _jc_method _jc_java_awt_image_FilteredImageSource$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_image_FilteredImageSource$vmethods {
	void	(*addConsumer$280f4229ae568632)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
	jboolean	(*isConsumer$2e7ee3184ebf4388)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*removeConsumer$c1effed99882a87d)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*requestTopDownLeftRightResend$9c3b642896e809d4)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*startProduction$34c5bb40595e132a)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_image_FilteredImageSource$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_image_FilteredImageSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_image_FilteredImageSource$vmethods	java_awt_image_FilteredImageSource;
};

// Vtype
struct _jc_java_awt_image_FilteredImageSource$vtype {
	_jc_type			type;
	_jc_java_awt_image_FilteredImageSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_image_FilteredImageSource$sub_refs {
	struct _jc_object	*ip;
	struct _jc_java_awt_image_ImageFilter$object	*filter;
	struct _jc_java_util_Hashtable$object	*consumers;
};

// Reference instance fields (object)
struct _jc_java_awt_image_FilteredImageSource$refs {
    _jc_java_awt_image_FilteredImageSource$sub_refs	java_awt_image_FilteredImageSource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_image_FilteredImageSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_image_FilteredImageSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_image_FilteredImageSource$sub_nonrefs	java_awt_image_FilteredImageSource;
};

// Object instance structure
struct _jc_java_awt_image_FilteredImageSource$object {
	_jc_java_awt_image_FilteredImageSource$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_image_FilteredImageSource$vtype	*vtype;
	_jc_java_awt_image_FilteredImageSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_image_FilteredImageSource$vtype _jc_java_awt_image_FilteredImageSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_image_FilteredImageSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_image_FilteredImageSource$class_object;

#endif	/* _JC_java_awt_image_FilteredImageSource_H_ */
